==> haskell-hxt-regex-xmlschema-9.2.0.3-8-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hxt-regex-xmlschema.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hxt-regex-xmlschema
version: 9.2.0.3
id: hxt-regex-xmlschema-9.2.0.3-WKEiNBuPmGJPoQftKO5hX
key: hxt-regex-xmlschema-9.2.0.3-WKEiNBuPmGJPoQftKO5hX
license: MIT
copyright: Copyright (c) 2010- Uwe Schmidt
maintainer: Uwe Schmidt <uwe@fh-wedel.de>
stability: stable
homepage: http://www.haskell.org/haskellwiki/Regular_expressions_for_XML_Schema
synopsis: A regular expression library for W3C XML Schema regular expressions
description:
    This library supports full W3C XML Schema regular expressions
    inclusive all Unicode character sets and blocks.
    The complete grammar can be found under <http://www.w3.org/TR/xmlschema11-2/#regexs>.
    It is implemented by the technique of derivations of regular expressions.
    .
    The W3C syntax is extended to support not only union of regular sets,
    but also intersection, set difference, exor.
    Matching of subexpressions is also supported.
    .
    The library can be used for constricting lightweight scanners and tokenizers.
    It is a standalone library, no external regex libraries are used.
    .
    Extensions in 9.2: The library does nor only support String'\''s, but also
    ByteString'\''s and Text in strict and lazy variants
category: Text
author: Uwe Schmidt
exposed: True
indefinite: False
exposed-modules:
    Text.Regex.Glob.Generic Text.Regex.Glob.Generic.RegexParser
    Text.Regex.Glob.String Text.Regex.XMLSchema.Generic
    Text.Regex.XMLSchema.Generic.Matching
    Text.Regex.XMLSchema.Generic.Regex
    Text.Regex.XMLSchema.Generic.RegexParser
    Text.Regex.XMLSchema.Generic.StringLike Text.Regex.XMLSchema.String
abi: 3eb9eba6a74d794d74968fd1a74ae9af
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/hxt-regex-xmlschema-9.2.0.3
library-dirs: /usr/lib/ghc-8.2.2/site-local/hxt-regex-xmlschema-9.2.0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/hxt-regex-xmlschema-9.2.0.3
hs-libraries: HShxt-regex-xmlschema-9.2.0.3-WKEiNBuPmGJPoQftKO5hX
depends:
    base-4.10.1.0 bytestring-0.10.8.2
    hxt-charproperties-9.2.0.1-AUb7E6mkZ2fDXtvIiRtV8v
    parsec-3.1.13.0-E3xu0p0JtSPICcgXxkVqap
    text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             hxt-charproperties-9.2.0.1-AUb7E6mkZ2fDXtvIiRtV8v=128140e73626722dd834f67c7ef8810c
             parsec-3.1.13.0-E3xu0p0JtSPICcgXxkVqap=e5bced146b6517b43ed5d06001479bde
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=b7726d921cac66adc5c8f9f66f5b25f0
haddock-interfaces: /usr/share/doc/haskell-hxt-regex-xmlschema/html/hxt-regex-xmlschema.haddock
haddock-html: /usr/share/doc/haskell-hxt-regex-xmlschema/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hxt-regex-xmlschema-9.2.0.3-9-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hxt-regex-xmlschema.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hxt-regex-xmlschema
version: 9.2.0.3
id: hxt-regex-xmlschema-9.2.0.3-HBeQMJB5xjo9wBO3m0UdGm
key: hxt-regex-xmlschema-9.2.0.3-HBeQMJB5xjo9wBO3m0UdGm
license: MIT
copyright: Copyright (c) 2010- Uwe Schmidt
maintainer: Uwe Schmidt <uwe@fh-wedel.de>
stability: stable
homepage: http://www.haskell.org/haskellwiki/Regular_expressions_for_XML_Schema
synopsis: A regular expression library for W3C XML Schema regular expressions
description:
    This library supports full W3C XML Schema regular expressions
    inclusive all Unicode character sets and blocks.
    The complete grammar can be found under <http://www.w3.org/TR/xmlschema11-2/#regexs>.
    It is implemented by the technique of derivations of regular expressions.
    .
    The W3C syntax is extended to support not only union of regular sets,
    but also intersection, set difference, exor.
    Matching of subexpressions is also supported.
    .
    The library can be used for constricting lightweight scanners and tokenizers.
    It is a standalone library, no external regex libraries are used.
    .
    Extensions in 9.2: The library does nor only support String'\''s, but also
    ByteString'\''s and Text in strict and lazy variants
category: Text
author: Uwe Schmidt
exposed: True
indefinite: False
exposed-modules:
    Text.Regex.Glob.Generic Text.Regex.Glob.Generic.RegexParser
    Text.Regex.Glob.String Text.Regex.XMLSchema.Generic
    Text.Regex.XMLSchema.Generic.Matching
    Text.Regex.XMLSchema.Generic.Regex
    Text.Regex.XMLSchema.Generic.RegexParser
    Text.Regex.XMLSchema.Generic.StringLike Text.Regex.XMLSchema.String
abi: 4e83e03bfc0b3f0adf0bcfad6bd44798
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/hxt-regex-xmlschema-9.2.0.3
library-dirs: /usr/lib/ghc-8.2.2/site-local/hxt-regex-xmlschema-9.2.0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/hxt-regex-xmlschema-9.2.0.3
hs-libraries: HShxt-regex-xmlschema-9.2.0.3-HBeQMJB5xjo9wBO3m0UdGm
depends:
    base-4.10.1.0 bytestring-0.10.8.2
    hxt-charproperties-9.2.0.1-AUb7E6mkZ2fDXtvIiRtV8v
    parsec-3.1.13.0-F9Bf3y6KXh0ILPjymhJoOp
    text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             hxt-charproperties-9.2.0.1-AUb7E6mkZ2fDXtvIiRtV8v=128140e73626722dd834f67c7ef8810c
             parsec-3.1.13.0-F9Bf3y6KXh0ILPjymhJoOp=b942a04aec0a266706b2e8e67bd137e3
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
haddock-interfaces: /usr/share/doc/haskell-hxt-regex-xmlschema/html/hxt-regex-xmlschema.haddock
haddock-html: /usr/share/doc/haskell-hxt-regex-xmlschema/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
